@@ -8,6 +8,7 @@ const SetStaticFieldHandler = require('./SetStaticFieldHandler')
 const ResolveReferenceHandler = require('./ResolveReferenceHandler')
 const CreateClassInstanceHandler = require('./CreateClassInstanceHandler')
 const GetInstanceFieldHandler = require('./GetInstanceFieldHandler')
+const SetInstanceFieldHandler = require('./SetInstanceFieldHandler')
 const InvokeInstanceMethodHandler = require('./InvokeInstanceMethodHandler')
 const DestructReferenceHandler = require("./DestructReferenceHandler");
 const CastHandler = require('./CastingHandler')
@@ -29,10 +30,6 @@ function isResponseSimpleType(response) {
     return ['string', 'boolean', 'number'].includes(type)
 }
 
-function isResponseArray(response) {
-    return response instanceof Array
-}
-
 function isResponseError(response) {
     return response instanceof Error
 }
@@ -48,6 +45,7 @@ const handlers = {
     [CommandType.Reference]: ResolveReferenceHandler,
     [CommandType.Cast]: CastHandler,
     [CommandType.GetInstanceField]: GetInstanceFieldHandler,
+    [CommandType.SetInstanceField]: SetInstanceFieldHandler,
     [CommandType.InvokeInstanceMethod]: InvokeInstanceMethodHandler,
     [CommandType.InvokeGlobalMethod]: InvokeGlobalMethodHandler,
     [CommandType.DestructReference]: DestructReferenceHandler,
@@ -59,8 +57,11 @@ const handlers = {
 }
 
 class Handler {
-
     handleCommand(command) {
+            if (command.commandType == CommandType.RetrieveArray) {
+                let responseArray = handlers[CommandType.Reference].handleCommand(command.payload[0])
+                return Command.createArrayResponse(responseArray, command.runtimeName)
+            }
             let response = handlers[command.commandType].handleCommand(command)
             if(isResponseError(response)) {
                 return ExceptionSerializer.serializeException(response, command)
