@@ -111,6 +111,26 @@ sub get_type {
     );
 }
 
+sub cast {
+    my $self = shift;
+    my @arguments = @_;
+
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Cast'),
+        payload => \@arguments
+    );
+
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+
 sub build_command {
     my $self = shift;
     my $command = shift;
